aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc-tkn4int.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2007-09-07 22:11:01 +0000
committerGuy Harris <guy@alum.mit.edu>2007-09-07 22:11:01 +0000
commit0366304ac96ced10270f9f5bca3947d9d9759428 (patch)
treec5d273d55f1d31afb102830d6fc134e696761e90 /epan/dissectors/packet-dcerpc-tkn4int.c
parentc360b112a102a26a0fd61c8d81f66559dc5be706 (diff)
Change the long protocol name dissectors for various DFS protocols to
indicate that they're for DFS; update comments as well. Rename packet-dcerpc-afs4int.c to packet-dcerpc-fileexp.c, and change the short and filter names for the protocol, and the names for the filterable fields, to reflect the fact that it's for the File Exporter protocol in DFS. ("AFS 4" = DCE DFS.) svn path=/trunk/; revision=22827
Diffstat (limited to 'epan/dissectors/packet-dcerpc-tkn4int.c')
-rw-r--r--epan/dissectors/packet-dcerpc-tkn4int.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-dcerpc-tkn4int.c b/epan/dissectors/packet-dcerpc-tkn4int.c
index 68afd63bb5..3c2b1bc650 100644
--- a/epan/dissectors/packet-dcerpc-tkn4int.c
+++ b/epan/dissectors/packet-dcerpc-tkn4int.c
@@ -1,6 +1,6 @@
/* packet-dcerpc-tkn4int.c
*
* Routines for dcerpc Token Server Calls
* Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
* This information is based off the released idl files from opengroup.
* ftp://ftp.opengroup.org/pub/dce122/dce/src/file.tar.gz file/fsint/tkn4int.idl
@@ -79,7 +79,7 @@ proto_register_tkn4int (void)
static gint *ett[] = {
&ett_tkn4int,
};
- proto_tkn4int = proto_register_protocol ("DCE/RPC TokenServer Calls", "TKN4Int", "tkn4int");
+ proto_tkn4int = proto_register_protocol ("DCE DFS Token Server", "TKN4Int", "tkn4int");
proto_register_field_array (proto_tkn4int, hf, array_length (hf));
proto_register_subtree_array (ett, array_length (ett));
}
@@ -1,6 +1,6 @@
/* packet-dcerpc-tkn4int.c
*
- * Routines for dcerpc Token Server Calls
+ * Routines for DCE DFS Token Server Calls
* Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
* This information is based off the released idl files from opengroup.